@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# Fusion 16.1.1-1 Debian package creator
-# Release 2020-01-10
+# Fusion 16.2.3-1 Debian package creator
+# Release 2020-07-05
 # By Daniel Tufvesson
 #
 
@@ -47,19 +47,19 @@ make_executable() {
 }
 
 # Setup variables
-FUSION_VERSION=16.1.1
+FUSION_VERSION=16.2.3
 DEB_STEPPING=1
 case $1 in
     studio)
 	FUSION_NAME="Blackmagic Fusion Studio"
-	INSTALLER_ARCHIVE=Blackmagic_Fusion_Studio_Linux_16.1.1_installer.run
+	INSTALLER_ARCHIVE=Blackmagic_Fusion_Studio_Linux_${FUSION_VERSION}_installer.run
 	DEB_NAME=blackmagic-fusion-studio
 	DEB_CONFLICTS=blackmagic-fusion
 	UNPACK_DIR=./unpack-Blackmagic_Fusion_StudioLinux_${FUSION_VERSION}_installer
 	;;
     lite)
 	FUSION_NAME="Blackmagic Fusion"
-	INSTALLER_ARCHIVE=Blackmagic_Fusion_Linux_16.1.1_installer.run
+	INSTALLER_ARCHIVE=Blackmagic_Fusion_Linux_${FUSION_VERSION}_installer.run
 	DEB_NAME=blackmagic-fusion
 	DEB_CONFLICTS=blackmagic-fusion-studio
 	UNPACK_DIR=./unpack-Blackmagic_Fusion_Linux_${FUSION_VERSION}_installer
@@ -103,22 +103,14 @@ copy_object ${UNPACK_DIR}/libfusionformats.so ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/libfusiongraphics.so ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/libfusionoperators.so ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/libfusionsystem.so ${FUSION_BASE_DIR}
+copy_object ${UNPACK_DIR}/libgpudetect.so ${FUSION_BASE_DIR}
+copy_object ${UNPACK_DIR}/libnvrtc-builtins.so ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/libnvrtc.so.10.0 ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/BlackmagicFusion.py ${FUSION_BASE_DIR}
 
-copy_object ${UNPACK_DIR}/Brushes ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Filters ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/Frameworks ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Fuses ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Guides ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/Help ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Layouts ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Library ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/LUTs ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Macros ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/Plugins ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Scripts ${FUSION_BASE_DIR}
-copy_object ${UNPACK_DIR}/Settings ${FUSION_BASE_DIR}
 copy_object ${UNPACK_DIR}/Skins ${FUSION_BASE_DIR}
 
 copy_object ${UNPACK_DIR}/Templates.zip ${FUSION_VAR_DIR}
@@ -145,6 +137,15 @@ MimeType=application/x-fusioncomp;
 Type=Application
 StartupNotify=true
 Categories=AudioVideo
+Actions=Config;Manager;
+
+[Desktop Action Config]
+Exec=/opt/BlackmagicDesign/Fusion16/Fusion -config
+Name=Configure Fusion 16
+
+[Desktop Action Manager]
+Exec=/opt/BlackmagicDesign/Fusion16/Fusion -manager
+Name=Fusion 16 Render Manager
 EOF
 
 # Create Debian package
